Module physical_fs

Module physical_fs 

Structs

PhysicalFSImpl
The physical filesystem, backed by a root on the drive.

Type Aliases

PhysicalFS
The physical filesystem, backed by a root on the drive. This filesystem will not protect against directory traversal and very simply appends the target path to the root.
SandboxedPhysicalFS
The physical filesystem, backed by a root on the drive. This filesystem will perform basic protections against directory traversal in the form of returning an error if a user tries to escape the current directory.