Module roc_fs

Module roc_fs 

Structs

RocFS
“Read-only collection” filesystem. Does not support writing, but supports reading from any of the layers. Differs from OverlayFS in that it only supports reading and is much less complex and doesn’t need to write a .whiteout directory that can sometimes prove problematic.