Structs
- TarFS
- A filesystem mounted on a Tarball archive, backed by a Memory FS.
Because the FS is backed by memory, all files are immediately loaded
into memory, so
filteredvariants of constructors should be used to avoid large files that may not need to be accessed.
Traits
- File
System Filter - Filters over filesystems.